Enum OperandKind
pub enum OperandKind {
Copy(Place),
Move(Place),
Constant {
konst: StoredConst,
ty: StoredTy,
},
Static(StaticId),
}Variants
Copy(Place)
Creates a value by loading the given place.
Before drop elaboration, the type of the place must be Copy. After drop elaboration there
is no such requirement.
Move(Place)
Creates a value by performing loading the place, just like the Copy operand.
This may additionally overwrite the place with uninit bytes, depending on how we decide
in UCG#188. You should not emit MIR that may attempt a subsequent second load of this
place without first re-initializing it.
Constant
Constants are already semantically values, and remain unchanged.
Static(StaticId)
NON STANDARD: This kind of operand returns an immutable reference to that static memory. Rustc
handles it with the Constant variant somehow.