Struct BasicBlock
pub struct BasicBlock {
pub statements: Vec<Statement>,
pub terminator: Option<Terminator>,
pub is_cleanup: bool,
}Fields
statements: Vec<Statement>List of statements in this block.
terminator: Option<Terminator>Terminator for this block.
N.B., this should generally ONLY be None during construction.
Therefore, you should generally access it via the
terminator() or terminator_mut() methods. The only
exception is that certain passes, such as simplify_cfg, swap
out the terminator temporarily with None while they continue
to recurse over the set of basic blocks.
is_cleanup: boolIf true, this block lies on an unwind path. This is used during codegen where distinct kinds of basic blocks may be generated (particularly for MSVC cleanup). Unwind blocks must only branch to other unwind blocks.